QWED Test Report - 2025-12-03

# 🛡️ QWED Comprehensive Test Audit

Generated: 2025-12-03 16:27:18

CRITICAL ISSUES
Total Tests
6
Passed
0
Failed
6
Pass Rate
0.0%
Duration
42.9s

## 📊 Results by Priority

Priority | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CRITICAL | 4 | 0 | 4 | 0.0%
HIGH | 2 | 0 | 2 | 0.0%
MEDIUM | 0 | 0 | 0 | 0.0%

## 🔧 Results by Engine

Engine | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
STATS | 6 | 0 | 6 | 0.0%

## ❌ Failed Tests (6)

### Detect os module in statistical code

Engine: stats Priority: HIGH ID: STATS_IMP_001
HTTP 500: Internal Server Error

### Detect subprocess in stats code

Engine: stats Priority: CRITICAL ID: STATS_IMP_002
HTTP 500: Internal Server Error

### Detect pickle.loads() RCE risk

Engine: stats Priority: CRITICAL ID: STATS_IMP_003
HTTP 500: Internal Server Error

### Detect DataFrame.eval() injection risk

Engine: stats Priority: CRITICAL ID: STATS_SEC_001
HTTP 500: Internal Server Error

### Detect exec() in analysis code

Engine: stats Priority: CRITICAL ID: STATS_SEC_002
HTTP 500: Internal Server Error

### Allow safe pandas operations

Engine: stats Priority: HIGH ID: STATS_SAFE_001
HTTP 500: Internal Server Error